@@ -358,6 +358,7 @@ time_units_factor <- c("days" = 24*3600,
 
 
 .parse_time <- function(time, units, calendar = NULL) {
+    calendar <- tolower(calendar)
     has_since <- grepl("since", units)
     if (!has_since) {
         return(time)
@@ -373,7 +374,7 @@ time_units_factor <- c("days" = 24*3600,
     }
 
 
-    if (!is.null(calendar)) {
+    if (length(calendar) != 0) {
         time <- as.POSIXct(PCICt::as.PCICt(time*time_units_factor[time_unit], cal = calendar, origin = origin),
                            cal = "standard", tz = "UTC", origin = origin)
     } else {
@@ -413,7 +414,7 @@ time_units_factor <- c("days" = 24*3600,
     new_subset <- subset[has_name]
     if (sum(!has_name) != 0) new_subset["chunks"] <- list(subset[!has_name])
 
-    chunks <- purrr::cross(new_subset)
+    chunks <- suppressWarnings(purrr::cross(new_subset))  # cross is deprecated
     new_subset <- lapply(chunks, function(chunk) {
         is.chunk <- which(names(chunk) == "chunks")
         if (length(is.chunk) != 0) {
