@@ -81,6 +81,7 @@ geom_contour_tanaka <- function(mapping = NULL, data = NULL,
                                 range = c(0.01, 0.5),
                                 smooth = 0,
                                 proj = NULL,
+                                proj.latlon = TRUE,
                                 clip = NULL,
                                 kriging = FALSE,
                                 na.rm = FALSE,
@@ -107,6 +108,7 @@ geom_contour_tanaka <- function(mapping = NULL, data = NULL,
             smooth = smooth,
             kriging = kriging,
             proj = proj,
+            proj.latlon = proj.latlon,
             clip = clip,
             ...
         )
